@@ -1,8 +1,9 @@
+import warnings
 from uuid import uuid4
 
-import attr
+from pydantic import BaseModel, Field
 
-from .core import Document, Preamble
+from .core import CZML_VERSION, Document, Packet
 
 TERRAIN = {
     "Cesium": "Cesium.createWorldTerrain()",
@@ -74,21 +75,28 @@ require(['cesium'], function (Cesium) {{
 """
 
 
-@attr.s
-class CZMLWidget:
-    document = attr.ib(default=Document([Preamble()]))
-    cesium_version = attr.ib(default="1.76")
-    ion_token = attr.ib(default="")
-    terrain = attr.ib(default=TERRAIN["Cesium"])
-    imagery = attr.ib(default=IMAGERY["Bing_Aerial"])
-
-    _container_id = attr.ib(factory=uuid4)
+class CZMLWidget(BaseModel):
+    warnings.warn(
+        "CZMLWidget is deprecated and will be removed in a future version.",
+        DeprecationWarning,
+        stacklevel=2,
+    )
+    document: Document = Field(
+        default=Document(
+            packets=[Packet(id="document", name="name", version=CZML_VERSION)]
+        )
+    )
+    cesium_version: str = Field(default="1.88")
+    ion_token: str = Field(default="")
+    terrain: str = Field(default=TERRAIN["Ellipsoid"])
+    imagery: str = Field(default=IMAGERY["OSM"])
+    container_id: str = Field(default=str(uuid4))
 
     def build_script(self):
         return SCRIPT_TPL.format(
             cesium_version=self.cesium_version,
-            czml=self.document.dumps(),
-            container_id=self._container_id,
+            czml=self.document.to_json(),
+            container_id=self.container_id,
             ion_token=self.ion_token,
             terrain=self.terrain,
             imagery=self.imagery,
@@ -98,7 +106,7 @@ class CZMLWidget:
         return CESIUM_TPL.format(
             cesium_version=self.cesium_version,
             script=self.build_script(),
-            container_id=self._container_id,
+            container_id=self.container_id,
             widget_height=widget_height,
         )
 
